<?php

//namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Capie_Elementor_Search_Form extends Elementor\Widget_Base {

	public function get_name() {
        return 'capie_search_form';
    }

	public function get_title() {
        return esc_html__( 'Apus Header Search Form', 'capie' );
    }
    
	public function get_categories() {
        return [ 'capie-header-elements' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Content', 'capie' ),
                'tab' => Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'show_categories',
            [
                'label' => esc_html__( 'Show Categories', 'capie' ),
                'type' => Elementor\Controls_Manager::SWITCHER,
                'default' => '',
                'label_on' => esc_html__( 'Show', 'capie' ),
                'label_off' => esc_html__( 'Hide', 'capie' ),
            ]
        );

        $this->add_control(
            'show_auto_search',
            [
                'label' => esc_html__( 'Show Autocomplete Search', 'capie' ),
                'type' => Elementor\Controls_Manager::SWITCHER,
                'default' => '',
                'label_on' => esc_html__( 'Show', 'capie' ),
                'label_off' => esc_html__( 'Hide', 'capie' ),
            ]
        );

        

        $this->add_responsive_control(
            'style',
            [
                'label' => esc_html__( 'Style', 'capie' ),
                'type' => Elementor\Controls_Manager::SELECT,
                'options' => [
                    'dropdown' => esc_html__( 'Dropdown', 'capie' ),
                    'clasic' => esc_html__( 'Clasic', 'capie' ),
                ],
                'default' => 'dropdown'
            ]
        );

   		$this->add_control(
            'el_class',
            [
                'label'         => esc_html__( 'Extra class name', 'capie' ),
                'type'          => Elementor\Controls_Manager::TEXT,
                'placeholder'   => esc_html__( 'If you wish to style particular content element differently, please add a class name to this field and refer to it in your custom CSS file.', 'capie' ),
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_title_style',
            [
                'label' => esc_html__( 'Title', 'capie' ),
                'tab' => Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'bg_color',
            [
                'label' => esc_html__( 'Background Color Button', 'capie' ),
                'type' => Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    // Stronger selector to avoid section style from overwriting
                    '{{WRAPPER}} .apus-search-form .btn' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'bg_border_color',
            [
                'label' => esc_html__( 'Border Color Button', 'capie' ),
                'type' => Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    // Stronger selector to avoid section style from overwriting
                    '{{WRAPPER}} .apus-search-form .btn' => 'border-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'bg_hover_color',
            [
                'label' => esc_html__( 'Background Hover Color Button', 'capie' ),
                'type' => Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    // Stronger selector to avoid section style from overwriting
                    '{{WRAPPER}} .apus-search-form .btn:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'bg_border_hover_color',
            [
                'label' => esc_html__( 'Border Hover Color Button', 'capie' ),
                'type' => Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    // Stronger selector to avoid section style from overwriting
                    '{{WRAPPER}} .apus-search-form .btn:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


    }

	protected function render() {
        $settings = $this->get_settings();

        extract( $settings );
        ?>
        <div class="apus-search-form <?php echo esc_attr($el_class.' '.$style); ?>">
            <a href="javascript:void(0);" class="show-search-form-btn"><i class="icon_search"></i></a>
            <form action="<?php echo esc_url( home_url( '/' ) ); ?>" method="get" class="<?php echo esc_attr($style == 'dropdown' ? 'search-form-popup-wrapper' : ''); ?>">
                <div class="form-group-search">
                    <?php 
                        if ( $show_categories && capie_is_woocommerce_activated() ) {
                            $args = array(
                                'show_count' => 0,
                                'hierarchical' => true,
                                'show_uncategorized' => 0
                            );
                            echo '<div class="select-category">';
                                wc_product_dropdown_categories( $args );
                            echo '</div>';
                        }
                    ?>
                    <div class="main-search">
                        <?php if ( $show_auto_search ) echo '<div class="twitter-typeahead">'; ?>
                            <input type="text" placeholder="<?php esc_attr_e( 'Search...', 'capie' ); ?>" name="s" class="apus-search form-control <?php echo esc_attr($show_auto_search ? 'apus-autocompleate-input' : ''); ?>" autocomplete="off"/>
                        <?php if ( $show_auto_search ) echo '</div>'; ?>
                    </div>
                    <input type="hidden" name="post_type" value="product" class="post_type" />                
                    <button type="submit" class="btn btn-theme radius-0">
                        <i class="icon_search"></i>
                    </button>
                </div>
            </form>
        </div>
        <?php
    }

}

if ( version_compare(ELEMENTOR_VERSION, '3.5.0', '<') ) {
    Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Capie_Elementor_Search_Form );
} else {
    Elementor\Plugin::instance()->widgets_manager->register( new Capie_Elementor_Search_Form );
}