<?php

//namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Capie_Elementor_Sidebar_Menu extends Elementor\Widget_Base {

	public function get_name() {
        return 'capie_header_sidebar_menu';
    }

	public function get_title() {
        return esc_html__( 'Apus Header Sidebar Menu', 'capie' );
    }
    
	public function get_categories() {
        return [ 'capie-header-elements' ];
    }

	protected function register_controls() {
        $custom_menus = array();
        $menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );
        if ( is_array( $menus ) && ! empty( $menus ) ) {
            foreach ( $menus as $menu ) {
                if ( is_object( $menu ) && isset( $menu->name, $menu->slug ) ) {
                    $custom_menus[ $menu->slug ] = $menu->name;
                }
            }
        }

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Content', 'capie' ),
                'tab' => Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'nav_menu',
            [
                'label' => esc_html__( 'Menu', 'capie' ),
                'type' => Elementor\Controls_Manager::SELECT,
                'options' => $custom_menus,
                'default' => ''
            ]
        );

        $this->add_control(
            'contact_info',
            [
                'label' => esc_html__( 'Contact Info', 'capie' ),
                'type' => Elementor\Controls_Manager::WYSIWYG,
                'default' => ''
            ]
        );

        $repeater = new Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'label' => esc_html__( 'Social Title', 'capie' ),
                'type' => Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'Social Title' , 'capie' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label' => esc_html__( 'Social Link', 'capie' ),
                'type' => Elementor\Controls_Manager::TEXT,
                'input_type' => 'url',
                'placeholder' => esc_html__( 'Enter your social link here', 'capie' ),
            ]
        );

        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__( 'Social Icon', 'capie' ),
                'type' => Elementor\Controls_Manager::ICON,
            ]
        );

        $this->add_control(
            'socials',
            [
                'label' => esc_html__( 'Socials', 'capie' ),
                'type' => Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );

   		$this->add_control(
            'el_class',
            [
                'label'         => esc_html__( 'Extra class name', 'capie' ),
                'type'          => Elementor\Controls_Manager::TEXT,
                'placeholder'   => esc_html__( 'If you wish to style particular content element differently, please add a class name to this field and refer to it in your custom CSS file.', 'capie' ),
            ]
        );

        $this->end_controls_section();
             
    }

	protected function render() {
        $settings = $this->get_settings();

        extract( $settings );

        $menu_id = 0;
        if ($nav_menu) {
            $term = get_term_by( 'slug', $nav_menu, 'nav_menu' );
            if ( !empty($term) ) {
                $menu_id = $term->term_id;
            }
        }

        ?>

        <div class="widget-sidebar-menu <?php echo esc_attr($el_class); ?>">
            <a href="javascript:void(0)" class="sidebar-menu-btn"><i class="icon_menu"></i></a>
            <div class="sidebar-menu-content">
                <div class="offcanvas-aside-content">
                    <?php if ( !empty($menu_id) ) { ?>
                        <div class="sidebar-menu-nav">
                            <?php
                                
                                $args = array(
                                    'menu'        => $menu_id,
                                    'container_class' => 'navbar-collapse navbar-offcanvas-collapse',
                                    'menu_class' => 'nav navbar-nav main-mobile-menu',
                                    'fallback_cb' => '',
                                    'menu_id' => '',
                                    'walker' => new Capie_Mobile_Menu()
                                );
                                wp_nav_menu($args);
                            ?>
                        </div>
                    <?php } ?>
                    <?php if ( !empty($contact_info) || !empty($socials) ) { ?>
                        <div class="sidebar-menu-bottom">
                            <?php if ( !empty($contact_info) ) { ?>
                                <div class="contact-info">
                                    <?php echo wp_kses_post($contact_info); ?>
                                </div>
                            <?php } ?>

                            <?php if ( !empty($socials) ) { ?>
                                <div class="widget-social <?php echo esc_attr($el_class); ?>">
                                    <ul class="social list-inline">
                                        <?php foreach ($socials as $social) { ?>
                                            <?php if ( !empty($social['link']) && !empty($social['icon']) ) { ?>
                                                <li>
                                                    <a href="<?php echo esc_url($social['link']);?>" <?php echo wp_kses_post(!empty($social['title']) ? 'title="'.$social['title'].'"' : ''); ?>>
                                                        <i class="<?php echo esc_attr($social['icon']); ?>"></i>
                                                    </a>
                                                </li>
                                            <?php } ?>
                                        <?php } ?>
                                    </ul>
                                </div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                </div>
            </div>
        </div>
        <?php
    }
}

if ( version_compare(ELEMENTOR_VERSION, '3.5.0', '<') ) {
    Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Capie_Elementor_Sidebar_Menu );
} else {
    Elementor\Plugin::instance()->widgets_manager->register( new Capie_Elementor_Sidebar_Menu );
}