<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Capie_Elementor_Banner extends Widget_Base {

	public function get_name() {
        return 'capie_banner';
    }

	public function get_title() {
        return esc_html__( 'Apus Banner', 'capie' );
    }
    
	public function get_categories() {
        return [ 'capie-elements' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Banner', 'capie' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'capie' ),
                'type' => Controls_Manager::TEXTAREA,
                'placeholder' => esc_html__( 'Enter your title here', 'capie' ),
            ]
        );
        $this->add_control(
            'subtitle',
            [
                'label' => esc_html__( 'SubTitle', 'capie' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'text',
                'placeholder' => esc_html__( 'Enter your subtitle here', 'capie' ),
            ]
        );
        $this->add_control(
            'img_bg_src',
            [
                'name' => 'image',
                'label' => esc_html__( 'Image Background', 'capie' ),
                'type' => Controls_Manager::MEDIA,
                'placeholder'   => esc_html__( 'Upload Image Background Here', 'capie' ),
            ]
        );
        $this->add_responsive_control(
            'banner_height',
            [
                'label' => esc_html__( 'Banner Height', 'capie' ),
                'type' => Controls_Manager::NUMBER,
                'selectors' => [
                    '{{WRAPPER}} .widget-banner' => 'height: {{VALUE}}px;',
                ],
            ]
        );
        $this->add_responsive_control(
            'img_align',
            [
                'label' => esc_html__( 'Image Alignment', 'capie' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'capie' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'capie' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'capie' ),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'capie' ),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .banner-image' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'link',
            [
                'label'       => esc_html__( 'URL', 'capie' ),
                'type'        => Controls_Manager::TEXT,
                'input_type'  => 'url',
                'placeholder' => esc_html__( 'Enter your Button Link here', 'capie' ),
                'default'     => '#',
            ]
        );

        $this->add_control(
            'content',
            [
                'label' => esc_html__( 'Content', 'capie' ),
                'type' => Controls_Manager::WYSIWYG,
                'placeholder' => esc_html__( 'Enter your content here', 'capie' ),
            ]
        );

        $this->add_control(
            'btn_text',
            [
                'label' => esc_html__( 'Button Text', 'capie' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter your button text here', 'capie' ),
            ]
        );

        $this->add_control(
            'btn_style',
            [
                'label' => esc_html__( 'Button Style', 'capie' ),
                'type' => Controls_Manager::SELECT,
                'options' => array(
                    'default'   => esc_html__('Default', 'capie'),                    
                    'shadow'    => esc_html__('Shadow ', 'capie'),
                    'white'     => esc_html__('White ', 'capie'),
                    'uppercase' => esc_html__('Simple Uppercase ', 'capie'),                    
                ),
                'default' => 'default'
            ]
        );

        $this->add_control(
            'style',
            [
                'label' => esc_html__( 'Style', 'capie' ),
                'type' => Controls_Manager::SELECT,
                'options' => array(
                    'style1' => esc_html__('Style 1 - (H: 380px)', 'capie'),
                    'style2' => esc_html__('Style 2 - (H: 370px)', 'capie'),
                    'style3' => esc_html__('Style 3 - (H: 370px)', 'capie'),
                    'style4' => esc_html__('Style 4 - (H: 370px)', 'capie'),
                    'style5' => esc_html__('Style 5 - (H: 340px)', 'capie'),
                    'style6' => esc_html__('Style 6 - (H: 470px)', 'capie'),
                    'style7' => esc_html__('Style 7 - (H: 500px)', 'capie'),
                    'style8' => esc_html__('Style 8 - (H: 598px)', 'capie'),
                    'style9' => esc_html__('Style 9 - (H: 666px)', 'capie'),
                    'style10' => esc_html__('Style 10 - (H: 376px)', 'capie'),                    
                    'style11' => esc_html__('Style 11 - (H: 383px Center Top)', 'capie'),                           
                    'style12' => esc_html__('Style 12 - (H: 383px Left Middle)', 'capie'),                           
                    'style13' => esc_html__('Style 13 - (H: 383px Right Middle)', 'capie'),                                               
                    'style14' => esc_html__('Style 14 - (H: 427px)', 'capie'),
                    'style15' => esc_html__('Style 15 - White Text', 'capie'),                    
                ),
                'default' => 'style1'                
            ]
        );

   		$this->add_control(
            'el_class',
            [
                'label'         => esc_html__( 'Extra class name', 'capie' ),
                'type'          => Controls_Manager::TEXT,
                'placeholder'   => esc_html__( 'If you wish to style particular content element differently, please add a class name to this field and refer to it in your custom CSS file.', 'capie' ),
            ]
        );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings();

        extract( $settings );

        $img_bg_src = ( isset( $img_bg_src['id'] ) && $img_bg_src['id'] != 0 ) ? wp_get_attachment_url( $img_bg_src['id'] ) : '';
        $style_bg = '';
        if ( !empty($img_bg_src) ) {
            $style_bg = 'style="background-image:url('.esc_url($img_bg_src).')"';
        }
        
        $style_height_output = '';
        if ( !empty($style_height) ) {
            $style_height_output = 'style="'.implode('', $style_height).'"';
        }
        
        ?>
        <div class="widget-banner <?php echo esc_attr($el_class.' '.$style); ?>" <?php echo trim($style_height_output); ?>>
            <div class="widget-banner-container">                 
                <?php if ( !empty($link) ) { ?>
                    <a href="<?php echo esc_url($link); ?>">
                <?php } ?>                    
                    <div class="inner">                        
                        <?php if ( !empty($content) || !empty($title) || !empty($subtitle) ) { ?>
                            <div class="p-static">
                                <div class="banner-content">
                                    <?php if ( !empty($subtitle) ) { ?>
                                        <div class="subtitle" >
                                           <span><?php echo trim( $subtitle ); ?></span>
                                        </div>
                                    <?php } ?>
                                    <?php if ( !empty($title) ) { ?>
                                        <div class="title">
                                            <?php echo trim( $title ); ?>  
                                        </div>
                                    <?php } ?>
                                    <?php if ( !empty($content) ) { ?>
                                        <?php echo wp_kses_post($content); ?>
                                    <?php } ?>
                                    <?php if ( !empty($btn_text) ) { ?>
                                        <div class="link-bottom">
                                            <span class="btn-banner <?php echo esc_attr(!empty($btn_style) ? $btn_style : ''); ?>"><?php echo wp_kses_post($btn_text); ?></span>
                                        </div>
                                    <?php } ?>
                                </div>
                            </div>
                        <?php } ?>
                    </div>
                    <div class="widget-banner-bg" <?php echo trim($style_bg); ?>></div>
                <?php if ( !empty($link) ) { ?>
                    </a>
                <?php } ?>
            </div>
        </div>
        <?php
    }
}

if ( version_compare(ELEMENTOR_VERSION, '3.5.0', '<') ) {
    Plugin::instance()->widgets_manager->register_widget_type( new Capie_Elementor_Banner );
} else {
    Plugin::instance()->widgets_manager->register( new Capie_Elementor_Banner );
}