<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Capie_Elementor_Lookbook extends Widget_Base {

	public function get_name() {
        return 'capie_lookbook';
    }

	public function get_title() {
        return esc_html__( 'Apus Lookbook', 'capie' );
    }
    
	public function get_categories() {
        return [ 'capie-elements' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Lookbook', 'capie' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'capie' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter your title here', 'capie' ),
            ]
        );        
        $this->add_control(
            'img_bg_src',
            [
                'name' => 'image',
                'label' => esc_html__( 'Image Background', 'capie' ),
                'type' => Controls_Manager::MEDIA,
                'placeholder'   => esc_html__( 'Upload Image Background Here', 'capie' ),
            ]
        );
        $this->add_control(
            'banner_height',
            [
                'label' => esc_html__( 'Banner Height', 'capie' ),
                'type' => Controls_Manager::NUMBER,
            ]
        );
        $this->add_control(
            'banner_width',
            [
                'label' => esc_html__( 'Banner Width', 'capie' ),
                'type' => Controls_Manager::NUMBER,
            ]
        );
        $this->add_responsive_control(
            'img_align',
            [
                'label' => esc_html__( 'Image Alignment', 'capie' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'capie' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'capie' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'capie' ),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'capie' ),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .lookbook-image' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'link',
            [
                'label' => esc_html__( 'URL', 'capie' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'url',
                'placeholder' => esc_html__( 'Enter your Button Link here', 'capie' ),
            ]
        );

        $this->add_control(
            'content',
            [
                'label' => esc_html__( 'Content', 'capie' ),
                'type' => Controls_Manager::WYSIWYG,
                'placeholder' => esc_html__( 'Enter your content here', 'capie' ),
            ]
        );

        $this->add_control(
            'btn_text',
            [
                'label' => esc_html__( 'Button Text', 'capie' ),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter your button text here', 'capie' ),
            ]
        );
        $this->add_control(
            'style',
            [
                'label' => esc_html__( 'Style', 'capie' ),
                'type' => Controls_Manager::SELECT,
                'options' => array(
                    'vertical' => esc_html__('Vertical', 'capie'),
                    'horizontal-right' => esc_html__('Horizontal - Right', 'capie'),                        
                    'horizontal-left' => esc_html__('Horizontal - Left', 'capie'),                                            
                ),
                'default' => 'vertical'                
            ]
        );

   		$this->add_control(
            'el_class',
            [
                'label'         => esc_html__( 'Extra class name', 'capie' ),
                'type'          => Controls_Manager::TEXT,
                'placeholder'   => esc_html__( 'If you wish to style particular content element differently, please add a class name to this field and refer to it in your custom CSS file.', 'capie' ),
            ]
        );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings();

        extract( $settings );

        $img_bg_src = ( isset( $img_bg_src['id'] ) && $img_bg_src['id'] != 0 ) ? wp_get_attachment_url( $img_bg_src['id'] ) : '';
        $style_bg = '';

        if ( !empty($banner_height) && !empty($banner_width) ) {
            $size_banner[] = 'height:'.$banner_height.'px; width:'.$banner_width.'px;';
        }

        if ( !empty($img_bg_src) ) {
            $style_bg = 'style="background-image:url('.esc_url($img_bg_src).')"';
        }

        $size_banner_output = '';
        if ( !empty($size_banner) ) {
            $size_banner_output = 'style="'.implode('', $size_banner).'"';
        }

        ?>

        <div class="widget-lookbook <?php echo esc_attr($el_class.' '.$style); ?>">        
            <div class="widget-lookbook-container">  
                <?php if ( $style == 'vertical' ): ?>
                    <?php if ( !empty($link) ) { ?>
                        <a href="<?php echo esc_url($link); ?>">
                    <?php } ?>          
                        <div class="lookbook-pic">                            
                            <div class="lookbook-pic-wrap" <?php echo trim($size_banner_output); ?>>
                                <div class="widget-lookbook-bg" <?php echo trim($style_bg); ?>></div>
                            </div>
                        </div>
                        <div class="inner">                        
                            <?php if ( !empty($content) || !empty($title) ) { ?>
                                
                                <div class="lookbook-content">
                                    <?php if ( !empty($title) ) { ?>
                                        <h3 class="title">
                                            <?php echo trim( $title ); ?>  
                                        </h3>
                                    <?php } ?>
                                    <?php if ( !empty($content) ) { ?>
                                        <div class="content">
                                            <?php echo wp_kses_post($content); ?>
                                        </div>
                                    <?php } ?>
                                    <?php if ( !empty($btn_text) ) { ?>
                                        <div class="link-bottom">
                                            <span class="btn-lookbook"><?php echo wp_kses_post($btn_text); ?></span>
                                        </div>
                                    <?php } ?>
                                </div>
                                
                            <?php } ?>
                        </div>                    
                    <?php if ( !empty($link) ) { ?>
                        </a>
                    <?php } ?>
                <?php elseif ( $style == 'horizontal-right' ): ?>
                    <?php if ( !empty($link) ) { ?>
                        <a href="<?php echo esc_url($link); ?>" class="flex-middle">
                    <?php } ?>          
                        <div class="lookbook-pic">
                            <div class="lookbook-pic-wrap" <?php echo trim($size_banner_output); ?>>
                                <div class="widget-lookbook-bg" <?php echo trim($style_bg); ?>></div>
                            </div>                            
                        </div>                        
                        <div class="inner">                        
                            <?php if ( !empty($content) || !empty($title) ) { ?>
                                
                                <div class="lookbook-content">
                                    <?php if ( !empty($title) ) { ?>
                                        <h3 class="title">
                                            <?php echo trim( $title ); ?>  
                                        </h3>
                                    <?php } ?>
                                    <?php if ( !empty($content) ) { ?>
                                        <div class="content">
                                            <?php echo wp_kses_post($content); ?>
                                        </div>
                                    <?php } ?>
                                    <?php if ( !empty($btn_text) ) { ?>
                                        <div class="link-bottom">
                                            <span class="btn-lookbook"><?php echo wp_kses_post($btn_text); ?></span>
                                        </div>
                                    <?php } ?>
                                </div>
                                
                            <?php } ?>
                        </div>                                  
                    <?php if ( !empty($link) ) { ?>
                        </a>
                    <?php } ?>
                <?php else: ?>
                    <?php if ( !empty($link) ) { ?>
                        <a href="<?php echo esc_url($link); ?>" class="flex-middle">
                    <?php } ?>                                  
                        <div class="inner">                        
                            <?php if ( !empty($content) || !empty($title) ) { ?>
                                
                                <div class="lookbook-content">
                                    <?php if ( !empty($title) ) { ?>
                                        <h3 class="title">
                                            <?php echo trim( $title ); ?>  
                                        </h3>
                                    <?php } ?>
                                    <?php if ( !empty($content) ) { ?>
                                        <div class="content">
                                            <?php echo wp_kses_post($content); ?>
                                        </div>
                                    <?php } ?>
                                    <?php if ( !empty($btn_text) ) { ?>
                                        <div class="link-bottom">
                                            <span class="btn-lookbook"><?php echo wp_kses_post($btn_text); ?></span>
                                        </div>
                                    <?php } ?>
                                </div>
                                
                            <?php } ?>
                        </div>          
                        <div class="lookbook-pic">
                            <div class="lookbook-pic-wrap" <?php echo trim($size_banner_output); ?>>
                                <div class="widget-lookbook-bg" <?php echo trim($style_bg); ?>></div>
                            </div>                            
                        </div>
                    <?php if ( !empty($link) ) { ?>
                        </a>
                    <?php } ?>
                <?php endif; ?>
            </div>
        </div>
        <?php
    }
}

if ( version_compare(ELEMENTOR_VERSION, '3.5.0', '<') ) {
    Plugin::instance()->widgets_manager->register_widget_type( new Capie_Elementor_Lookbook );
} else {
    Plugin::instance()->widgets_manager->register( new Capie_Elementor_Lookbook );
}