<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Capie_Elementor_Woo_Category_Banner extends Widget_Base {

	public function get_name() {
        return 'capie_woo_category_banner';
    }

	public function get_title() {
        return esc_html__( 'Apus Categories Banner', 'capie' );
    }

    public function get_icon() {
        return 'fa fa-shopping-bag';
    }

	public function get_categories() {
        return [ 'capie-elements' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Content', 'capie' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'label' => esc_html__( 'Category Title', 'capie' ),
                'type' => Controls_Manager::TEXT
            ]
        );

        $repeater->add_control(
            'slug', [
                'label' => esc_html__( 'Category Slug', 'capie' ),
                'type' => Controls_Manager::TEXT
            ]
        );

        $repeater->add_control(
            'img_src',
            [
                'name' => 'image',
                'label' => esc_html__( 'Category Image', 'capie' ),
                'type' => Controls_Manager::MEDIA,
                'placeholder'   => esc_html__( 'Upload Category Image', 'capie' ),
            ]
        );

        $this->add_control(
            'categories',
            [
                'label' => esc_html__( 'Category Banners', 'capie' ),
                'type' => Controls_Manager::REPEATER,
                'placeholder' => esc_html__( 'Enter your category banner here', 'capie' ),
                'fields' => $repeater->get_controls(),
            ]
        );

        $this->add_control(
            'columns',
            [
                'label' => esc_html__( 'Columns', 'capie' ),
                'type' => Controls_Manager::NUMBER,
                'input_type' => 'number',
                'default' => 4
            ]
        );

   		$this->add_control(
            'el_class',
            [
                'label'         => esc_html__( 'Extra class name', 'capie' ),
                'type'          => Controls_Manager::TEXT,
                'placeholder'   => esc_html__( 'If you wish to style particular content element differently, please add a class name to this field and refer to it in your custom CSS file.', 'capie' ),
            ]
        );

        $this->end_controls_section();

    }

	protected function render() {
        $settings = $this->get_settings();

        extract( $settings );

        if ( !empty($categories) ) {
        ?>
            <div class="widget-category-banner <?php echo esc_attr($el_class); ?>">
                <div class="slick-carousel" data-carousel="slick" data-items="<?php echo esc_attr($columns); ?>" data-smallmedium="2" data-extrasmall="1" data-pagination="false" data-nav="true">
                    <?php
                    foreach ($categories as $category) {
                        if ( !empty($category['slug']) ) {
                            $term = get_term_by('slug', $category['slug'], 'product_cat');
                            if ( $term ) {
                                $term_title = !empty($category['title']) ? $category['title'] : $term->name;
                                ?>
                                <div class="category-item">
                                    <a href="<?php echo esc_url(get_term_link($term)); ?>" title="<?php echo esc_attr($term->name); ?>">
                                        <?php if ( !empty($category['img_src']['id']) ) { ?>
                                            <?php echo wp_kses_post(capie_get_attachment_thumbnail($category['img_src']['id'], 'full')); ?>
                                        <?php } ?>
                                        <div class="category-intro-text">
                                            <div class="product-nb">
                                                <span><?php echo sprintf(_n('%d Product', '%d Products', $term->count, 'capie'), $term->count); ?></span>
                                            </div>
                                            <h3 class="cat-title">
                                                <span><?php echo wp_kses_post($term_title); ?></span>
                                            </h3>                                        
                                        </div>  
                                        <div class="category-intro-button">
                                            <span class="btn btn-shadow">
                                                <span><?php echo esc_html__( 'Shop now', 'capie' ); ?></span>
                                            </span>
                                        </div>                                        
                                    </a>
                                </div>
                                <?php
                            }
                        }
                    }
                    ?>
                </div>
            </div>
            <?php
        }
    }
}

if ( version_compare(ELEMENTOR_VERSION, '3.5.0', '<') ) {
    Plugin::instance()->widgets_manager->register_widget_type( new Capie_Elementor_Woo_Category_Banner );
} else {
    Plugin::instance()->widgets_manager->register( new Capie_Elementor_Woo_Category_Banner );
}